.. _tensor-array:

N-dim array
===========

.. automodule:: sympy.tensor.array


Classes
-------

.. autoclass:: ImmutableDenseNDimArray
   :members:

.. autoclass:: ImmutableSparseNDimArray
   :members:

.. autoclass:: MutableDenseNDimArray
   :members:

.. autoclass:: MutableSparseNDimArray
   :members:


Functions
---------

.. autofunction:: derive_by_array

.. autofunction:: permutedims

.. autofunction:: tensorcontraction

.. autofunction:: tensorproduct

.. autofunction:: tensordiagonal
